Легковесный Python модуль (в нескольких килобайтах) для генерации пароля

Что нового в версии 0.1.1👇

— Убрали некоторые артифакты в инструкции
— Добавили немного эмодзи для визуальности

Инструкция:
Passgen3 поддерживает только методы generate и generate_with_name и некоторые исключения

Все параметры метода generate👇

    Параметр            Тип                 Функция

    length              int	    Длина пароля (по умолчанию: 8)
    only_int	    bool	    Только цифры (0–9)
    without_int	    bool	    Без цифр (только буквы a–z, A–Z)
    only_letters	    bool	Только буквы (a–z, A–Z)
    upper_letters	    bool	Только заглавные буквы (A–Z)
    lower_letters	    bool	Только строчные буквы (a–z)
    special_symbols     bool    Включает специальные символы (!@#$%^&*()_+-=[]{}|;:,.<>?)    

Все параметры метода generate_with_name👇

    Параметр            Тип                 Функция
    
    name                str     Стартовое имя пароля (не будет влиять на другие параметры)
    length              int	    Длина пароля (по умолчанию: 8)
    only_int	    bool	    Только цифры (0–9)
    without_int	    bool	    Без цифр (только буквы a–z, A–Z)
    only_letters   	    bool	Только буквы (a–z, A–Z)
    upper_letters	    bool	Только заглавные буквы (A–Z)
    lower_letters	    bool	Только строчные буквы (a–z)
    special_symbols     bool    Включает специальные символы (!@#$%^&*()_+-=[]{}|;:,.<>?)

Все исключения👇

            Ошибка                                                          Значение(причина)


    ConfigurationConflictError                          Возникает в двух методах при конфликте параметров генерации.
        InvalidLengthError                  Возникает тоже в двух методах, если длина строки некорректна (≤ 0 или не целое число).
    InvalidOrEmptyNameError                 Возникает только в методе generate_with_name, если имя пустое или задана другим типом.